#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clientsession
version:              0.9.3.0
visibility:           public
id:                   clientsession-0.9.3.0-B8wuTj8XeNtD7nARNNTiE8
key:                  clientsession-0.9.3.0-B8wuTj8XeNtD7nARNNTiE8
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  b6c648bcaa61c9467e8d1b9b602afd27
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.3.0-B8wuTj8XeNtD7nARNNTiE8
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-HSSC8ZpQ1EiHU6Qv1r7ZrY
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    crypto-api-0.13.3-5Lfgsrp27JqCvocn2Yi2a9
    crypton-1.0.4-3mMbBQHl0K4EgHAKLusoNW directory-1.3.8.5
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    setenv-0.1.1.3-CVeJDG29Zk69t8Gaft7eyg
    skein-1.0.9.4-7TJQkP0Jw28167niipwkQ
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

